@@ -1755,8 +1755,10 @@ class Imagen(nn.Module):
 
         # unet image sizes
 
-        self.image_sizes = cast_tuple(image_sizes)
-        assert num_unets == len(image_sizes), f'you did not supply the correct number of u-nets ({len(self.unets)}) for resolutions {image_sizes}'
+        image_sizes = cast_tuple(image_sizes)
+        self.image_sizes = image_sizes
+
+        assert num_unets == len(image_sizes), f'you did not supply the correct number of u-nets ({len(unets)}) for resolutions {image_sizes}'
 
         self.sample_channels = cast_tuple(self.channels, num_unets)
 
